Home
last modified time | relevance | path

Searched refs:overload (Results 1 – 25 of 75) sorted by relevance

123

/llvm-project-15.0.7/clang/test/Sema/
H A Doverload-arm-mve.c50 int test_easy_s16(void) { return overload(vs16, s16); } in test_easy_s16()
54 int test_easy_u16(void) { return overload(vu16, u16); } in test_easy_u16()
58 int test_easy_s32(void) { return overload(vs32, s32); } in test_easy_s32()
62 int test_easy_u32(void) { return overload(vu32, u32); } in test_easy_u32()
70 int test_promote_s16(void) { return overload(vs16, s16 + 1); } in test_promote_s16()
74 int test_promote_u16(void) { return overload(vu16, u16 + 1); } in test_promote_u16()
78 int test_promote_s32(void) { return overload(vs32, s32 + 1); } in test_promote_s32()
91 int test_literal_s16(void) { return overload(vs16, 1); } in test_literal_s16()
95 int test_literal_u16(void) { return overload(vu16, 1); } in test_literal_u16()
99 int test_literal_s32(void) { return overload(vs32, 1); } in test_literal_s32()
[all …]
/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Daddr-of-overloaded-fn.cu8 __host__ void overload() {} in overload() function
9 __device__ void overload() {} in overload() function
14 void (*x)() = overload; in test_hd()
20 void (*x)() = overload; in test_host()
23 void (*x)() = overload; in test_device()
/llvm-project-15.0.7/clang/test/CXX/expr/expr.prim/expr.prim.lambda/
H A Dp5-generic-lambda-1y.cpp14 template <class F1, class F2> struct overload : F1, F2 { struct
17 overload(F1 f1, F2 f2) : F1(f1), F2(f2) { } in overload() function
26 overload<decltype(Base), decltype(NumParams)> O(Base, NumParams);
32 template <class F1, class F2> struct overload : F1, F2 { struct
35 overload(F1 f1, F2 f2) : F1(f1), F2(f2) { } in overload() function
44 overload<decltype(Base), decltype(NumParams)> O(Base, NumParams);
/llvm-project-15.0.7/clang/test/SemaObjCXX/
H A Doverload.mm173 // it's okay to overload Class with id.
186 int overload(NSDictionary *) { return 1; }
188 __attribute__((deprecated)) // expected-note {{'overload' has been explicitly marked deprecated he…
189 int overload(NSMutableDictionary *) { return 0; }
196 overload(d1);
197 overload(d2); // no warning
198 overload(m1); // expected-warning {{'overload' is deprecated}}
H A Dunknown-anytype.mm47 // - get this call through overload resolution somehow,
/llvm-project-15.0.7/mlir/python/mlir/_mlir_libs/_mlir/
H A Dir.pyi108 @overload
110 @overload
145 @overload
147 @overload
169 @overload
171 @overload
187 @overload
189 @overload
200 @overload
202 @overload
[all …]
/llvm-project-15.0.7/clang/test/AST/
H A Dast-dump-recovery.cpp139 int overload();
140 int overload(int, int);
156 f.overload(1); in test2()
/llvm-project-15.0.7/clang/test/SemaTemplate/
H A Ddependent-expr.cpp148 template<class ...Ts> struct overload : Ts... { struct
149 overload(Ts ...ts) : Ts(decltype(ts)(ts))... {} in overload() argument
160 return decltype(overload(f0, f1, f2, f3)(T(), 0))(); in num_bindings()
/llvm-project-15.0.7/clang-tools-extra/docs/clang-tidy/checks/abseil/
H A Dfaster-strsplit-delimiter.rst23 // overload of absl::StrSplit() to be used.
31 // overload of absl::StrSplit() to be used and we do not need absl::ByAnyChar
40 // overload of absl::StrSplit() to be used.
/llvm-project-15.0.7/mlir/python/mlir/dialects/
H A D_transform_ops_ext.py12 from typing import Optional, overload, Sequence, Union
80 @overload
85 @overload
/llvm-project-15.0.7/clang-tools-extra/docs/clang-tidy/checks/bugprone/
H A Dinaccurate-erase.rst13 removed due to using an inappropriate overload.
23 Call the two-argument overload of ``erase()`` to remove the subrange:
H A Dstringview-nullptr.rst14 explicitly-deleted overload to catch some of these cases: wg21.link/p2166
55 constructor overload and then value-initializes the pointer, causing a null
H A Dforwarding-reference-overload.rst1 .. title:: clang-tidy - bugprone-forwarding-reference-overload
3 bugprone-forwarding-reference-overload
/llvm-project-15.0.7/clang/test/SemaObjC/
H A Dovl-check.m4 // in overload resolution in ObjC.
55 // Overload resolution should occur silently, select the CFTypeRef overload,
/llvm-project-15.0.7/clang/test/SemaOpenCLCXX/
H A Daddress-space-references.clcpp8 //FIXME: With the overload below the call should be resolved
9 // successfully. However, current overload resolution logic
/llvm-project-15.0.7/llvm/docs/
H A DCompileCudaWithLLVM.rst309 However, nvcc allows you to "overload" H and D functions with different
344 overload resolution. See `IdentifyCUDAPreference
373 foo(); // calls H overload
374 bar(); // calls H overload
378 foo(); // calls D overload
379 bar(); // calls HD overload
383 foo(); // calls H overload when compiling for host, otherwise D overload
384 bar(); // always calls HD overload
449 // have ifdef'ed away the __device__ overload of S::foo(). The __device__
450 // overload must be present *even during host compilation*.
[all …]
/llvm-project-15.0.7/clang/test/Modules/
H A Dmalformed-overload.m2 // RUN: %clang_cc1 -fsyntax-only -I%S/Inputs/malformed-overload -fmodules -fimplicit-module-maps -f…
/llvm-project-15.0.7/clang-tools-extra/docs/clang-tidy/checks/performance/
H A Dfaster-string-find.rst7 a single character string literal. The character literal overload is more
/llvm-project-15.0.7/lld/test/ELF/
H A Dundef-suggest-extern-c2.s5 ## C++ overload.
/llvm-project-15.0.7/clang/test/SemaOpenCL/
H A Dcl20-device-side-enqueue.cl23 // Testing the first overload type
46 // Testing the second overload type
71 // Testing the third overload type
144 // Testing the forth overload type
/llvm-project-15.0.7/llvm/test/DebugInfo/PDB/
H A Devery-type.test79 TYPES-NEXT: - LF_METHOD [name = `Inherit`, # overloads = 2, overload list = 0x1014]
141 TYPES-NEXT: - LF_METHOD [name = `VInherit`, # overloads = 3, overload list = 0x1026]
142 TYPES-NEXT: - LF_METHOD [name = `operator=`, # overloads = 2, overload list = 0x102A]
198 TYPES-NEXT: - LF_METHOD [name = `IVInherit`, # overloads = 3, overload list = 0x1037]
199 TYPES-NEXT: - LF_METHOD [name = `operator=`, # overloads = 2, overload list = 0x103B]
242 TYPES-NEXT: - LF_METHOD [name = `OverloadedMethod`, # overloads = 2, overload list = 0x1…
/llvm-project-15.0.7/clang/test/SemaCXX/
H A Dunqualified-std-call.cpp81 namespace overload { namespace
/llvm-project-15.0.7/clang/test/Headers/
H A Dopencl-builtins.cl17 // overload resolution will cause this test to fail.
/llvm-project-15.0.7/llvm/lib/Target/DirectX/
H A DDXIL.td40 string llvm_type = type; // llvm type name, $o for overload, $r for resource
61 string oload_types = ""; // overload types if applicable
/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/
H A Dalgorithm39 // overload preceding it. So the simple thing to do would be to declare our
52 // overload resolution will prefer it over the __host__ __device__ version

123